/*
 * Copyright © 2024 Igalia S.L.
 * SPDX-License-Identifier: MIT
 */

#pragma once

#include "util/macros.h"

#ifdef __cplusplus
extern "C" {
#endif

enum PACKED isa_cond {
   ISA_COND_TRUE = 0,
   ISA_COND_GT = 1,
   ISA_COND_LT = 2,
   ISA_COND_GE = 3,
   ISA_COND_LE = 4,
   ISA_COND_EQ = 5,
   ISA_COND_NE = 6,
   ISA_COND_AND = 7,
   ISA_COND_OR = 8,
   ISA_COND_XOR = 9,
   ISA_COND_NOT = 10,
   ISA_COND_NZ = 11,
   ISA_COND_GEZ = 12,
   ISA_COND_GZ = 13,
   ISA_COND_LEZ = 14,
   ISA_COND_LZ = 15,
   ISA_COND_SELMSB = 22,
};

enum PACKED isa_swiz {
   ISA_SWIZ_X = 0,
   ISA_SWIZ_Y = 1,
   ISA_SWIZ_Z = 2,
   ISA_SWIZ_W = 3,
};

enum PACKED isa_type {
   ISA_TYPE_F32 = 0,
   ISA_TYPE_S32 = 1,
   ISA_TYPE_S8 = 2,
   ISA_TYPE_U16 = 3,
   ISA_TYPE_F16 = 4,
   ISA_TYPE_S16 = 5,
   ISA_TYPE_U32 = 6,
   ISA_TYPE_U8 = 7,
};

enum PACKED isa_reg_group {
   ISA_REG_GROUP_TEMP = 0,
   ISA_REG_GROUP_INTERNAL = 1,
   ISA_REG_GROUP_UNIFORM_0 = 2,
   ISA_REG_GROUP_UNIFORM_1 = 3,
   ISA_REG_GROUP_TH = 4,
   ISA_REG_GROUP_IMMED = 7,
};

enum PACKED isa_reg_addressing_mode {
   ISA_REG_ADDRESSING_MODE_DIRECT = 0,
   ISA_REG_ADDRESSING_MODE_AX = 1,
   ISA_REG_ADDRESSING_MODE_AY = 2,
   ISA_REG_ADDRESSING_MODE_AZ = 3,
   ISA_REG_ADDRESSING_MODE_AW = 4,
};

enum PACKED isa_rounding {
   ISA_ROUNDING_ = 0,
   ISA_ROUNDING_RTZ = 1,
   ISA_ROUNDING_RTNE = 2,
   ISA_ROUNDING_UNKOWN = 3,
   ISA_ROUNDING_UNKOWN2 = 4,
};

enum PACKED isa_wrmask {
   ISA_WRMASK_____ = 0,
   ISA_WRMASK_X___ = 1,
   ISA_WRMASK__Y__ = 2,
   ISA_WRMASK_XY__ = 3,
   ISA_WRMASK___Z_ = 4,
   ISA_WRMASK_ZX = 5,
   ISA_WRMASK_ZY = 6,
   ISA_WRMASK_XYZ_ = 7,
   ISA_WRMASK____W = 8,
   ISA_WRMASK_X__W = 9,
   ISA_WRMASK__Y_W = 10,
   ISA_WRMASK_XY_W = 11,
   ISA_WRMASK___ZW = 12,
   ISA_WRMASK_X_ZW = 13,
   ISA_WRMASK__YZW = 14,
   ISA_WRMASK_ = 15,
};

enum PACKED isa_thread {
   ISA_THREAD_ = 0,
   ISA_THREAD_T0 = 1,
   ISA_THREAD_T1 = 2,
};

enum PACKED isa_opc {
   ISA_OPC_NOP = 0,
   ISA_OPC_ADD = 1,
   ISA_OPC_MAD = 2,
   ISA_OPC_MUL = 3,
   ISA_OPC_DP3 = 5,
   ISA_OPC_DP4 = 6,
   ISA_OPC_DSX = 7,
   ISA_OPC_DSY = 8,
   ISA_OPC_MOV = 9,
   ISA_OPC_MOVAR = 10,
   ISA_OPC_RCP = 12,
   ISA_OPC_RSQ = 13,
   ISA_OPC_SELECT = 15,
   ISA_OPC_SET = 16,
   ISA_OPC_EXP = 17,
   ISA_OPC_LOG = 18,
   ISA_OPC_FRC = 19,
   ISA_OPC_CALL = 20,
   ISA_OPC_RET = 21,
   ISA_OPC_BRANCH = 22,
   ISA_OPC_TEXKILL = 23,
   ISA_OPC_TEXLD = 24,
   ISA_OPC_TEXLDB = 25,
   ISA_OPC_TEXLDD = 26,
   ISA_OPC_TEXLDL = 27,
   ISA_OPC_SQRT = 33,
   ISA_OPC_SIN = 34,
   ISA_OPC_COS = 35,
   ISA_OPC_BRANCH_ANY = 36,
   ISA_OPC_FLOOR = 37,
   ISA_OPC_CEIL = 38,
   ISA_OPC_SIGN = 39,
   ISA_OPC_BARRIER = 42,
   ISA_OPC_I2I = 44,
   ISA_OPC_I2F = 45,
   ISA_OPC_F2I = 46,
   ISA_OPC_F2IRND = 47,
   ISA_OPC_CMP = 49,
   ISA_OPC_LOAD = 50,
   ISA_OPC_STORE = 51,
   ISA_OPC_IADDSAT = 59,
   ISA_OPC_IMULLO0 = 60,
   ISA_OPC_IMULHI0 = 64,
   ISA_OPC_IDIV0 = 68,
   ISA_OPC_IMOD = 72,
   ISA_OPC_IMADLO0 = 76,
   ISA_OPC_IMADLOSAT0 = 78,
   ISA_OPC_MOVAI = 86,
   ISA_OPC_IABS = 87,
   ISA_OPC_LEADZERO = 88,
   ISA_OPC_LSHIFT = 89,
   ISA_OPC_RSHIFT = 90,
   ISA_OPC_ROTATE = 91,
   ISA_OPC_OR = 92,
   ISA_OPC_AND = 93,
   ISA_OPC_XOR = 94,
   ISA_OPC_NOT = 95,
   ISA_OPC_BIT_EXTRACT = 96,
   ISA_OPC_POPCOUNT = 97,
   ISA_OPC_DIV = 100,
   ISA_OPC_ATOMIC_ADD = 101,
   ISA_OPC_ATOMIC_XCHG = 102,
   ISA_OPC_ATOMIC_CMP_XCHG = 103,
   ISA_OPC_ATOMIC_MIN = 104,
   ISA_OPC_ATOMIC_MAX = 105,
   ISA_OPC_ATOMIC_OR = 106,
   ISA_OPC_ATOMIC_AND = 107,
   ISA_OPC_ATOMIC_XOR = 108,
   ISA_OPC_BIT_REV = 109,
   ISA_OPC_TEXLDLPCF = 111,
   ISA_OPC_DP2 = 115,
   ISA_OPC_NORM_DP2 = 116,
   ISA_OPC_NORM_DP3 = 117,
   ISA_OPC_NORM_DP4 = 118,
};


#ifdef __cplusplus
} /* extern C */
#endif

